@@ -30,6 +30,7 @@ from lilya.datastructures import URL, Header, ScopeHandler, SendReceiveSniffer,
 from lilya.dependencies import wrap_dependency
 from lilya.enums import EventType, HTTPMethod, Match, ScopeType
 from lilya.exceptions import ContinueRouting, HTTPException, ImproperlyConfigured
+from lilya.lifecycle import get_hooks as _lifecycle_get_hooks
 from lilya.middleware.base import DefineMiddleware
 from lilya.permissions.base import DefinePermission
 from lilya.requests import Request
@@ -1217,10 +1218,21 @@ class BaseRouter:
         self.on_startup = [] if on_startup is None else list(on_startup)
         self.on_shutdown = [] if on_shutdown is None else list(on_shutdown)
 
+        # Inject global lifecycle hooks (from lilya.lifecycle)
+        hooks = _lifecycle_get_hooks()
+
+        # Global startup hooks run before app-defined ones
+        self.on_startup = [*hooks["startup"], *self.on_startup]
+
+        # Global shutdown hooks run after app-defined ones
+        self.on_shutdown = [*self.on_shutdown, *hooks["shutdown"]]
+
         # Wrap dependencies
         _dependencies = dependencies if dependencies is not None else {}
         self.dependencies = {key: wrap_dependency(dep) for key, dep in _dependencies.items()}
 
+        self.dependency_overrides: dict[str, Any] = {}
+
         self.lifespan_context = handle_lifespan_events(
             on_startup=on_startup, on_shutdown=on_shutdown, lifespan=lifespan
         )
@@ -1322,8 +1334,20 @@ class BaseRouter:
             route: The matched route.
             path_handler (PathHandler): The PathHandler.
         """
-        new_scope = dict(path_handler.scope)
-        new_scope.update(path_handler.child_scope)
+        base_scope = path_handler.scope
+        child = path_handler.child_scope or {}
+
+        if "path_params" in child:
+            base_scope.setdefault("path_params", {}).update(child["path_params"])
+        # expose the matched route + template
+        base_scope["route"] = route
+        base_scope["route_path_template"] = getattr(route, "path", None)
+
+        if self.dependency_overrides:
+            base_scope["dependency_overrides"] = self.dependency_overrides
+
+        new_scope = dict(base_scope)
+        new_scope.update(child)
         await route.handle_dispatch(new_scope, path_handler.receive, path_handler.send)  # type: ignore
 
     async def handle_partial(self, route: BasePath, path_handler: PathHandler) -> None:
